==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/controllers/user_ranks_controller.rb <==
# -*- coding: utf-8 -*-
class UserRanksController < ApplicationController
  class_desc :display_name => "会員ランク管理"

  # GET /user_ranks
  # GET /user_ranks.xml
  def index
    @condition = prepare_session_condition do |condition|
      condition || UserRank::SearchForm.new(params[:condition])
    end
    
    @user_ranks = UserRank.paginate(@condition.to_paginate_options(:page => params[:page]))

    respond_to do |format|
      format.html # index.html.erb
      format.xml  { render :xml => @user_ranks }
    end
  end

  # GET /user_ranks/1
  # GET /user_ranks/1.xml
  def show
    @user_rank = UserRank.find(params[:id])

    respond_to do |format|
      format.html # show.html.erb
      format.xml  { render :xml => @user_rank }
    end
  end

  # GET /user_ranks/new
  # GET /user_ranks/new.xml
  def new
    @user_rank = UserRank.new

    respond_to do |format|
      format.html # new.html.erb
      format.xml  { render :xml => @user_rank }
    end
  end

  # GET /user_ranks/1/edit
  def edit
    @user_rank = UserRank.find(params[:id])
  end

  # POST /user_ranks
  # POST /user_ranks.xml
  def create
    @user_rank = UserRank.new(params[:user_rank])

    respond_to do |format|
      if @user_rank.save
        flash[:notice] = 'UserRank was successfully created.'
        format.html { redirect_to(@user_rank) }
        format.xml  { render :xml => @user_rank, :status => :created, :location => @user_rank }
      else
        format.html { render :action => "new" }
        format.xml  { render :xml => @user_rank.errors, :status => :unprocessable_entity }
      end
    end
  end

  # PUT /user_ranks/1
  # PUT /user_ranks/1.xml
  def update
    @user_rank = UserRank.find(params[:id])

    respond_to do |format|
      if @user_rank.update_attributes(params[:user_rank])
        flash[:notice] = 'UserRank was successfully updated.'
        format.html { redirect_to(@user_rank) }
        format.xml  { head :ok }
      else
        format.html { render :action => "edit" }
        format.xml  { render :xml => @user_rank.errors, :status => :unprocessable_entity }
      end
    end
  end

  # DELETE /user_ranks/1
  # DELETE /user_ranks/1.xml
  def destroy
    @user_rank = UserRank.find(params[:id])
    @user_rank.destroy

    respond_to do |format|
      format.html { redirect_to(user_ranks_url) }
      format.xml  { head :ok }
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/controllers/user_ranks_controller.rb <==
# -*- coding: utf-8 -*-
class UserRanksController < ApplicationController
  class_desc :display_name => "会員ランク管理"

  # GET /user_ranks
  # GET /user_ranks.xml
  def index
    @condition = prepare_session_condition do |condition|
      condition || UserRank::SearchForm.new(params[:condition])
    end
    
    @user_ranks = UserRank.paginate(@condition.to_paginate_options(:page => params[:page]))

    respond_to do |format|
      format.html # index.html.erb
      format.xml  { render :xml => @user_ranks }
    end
  end

  # GET /user_ranks/1
  # GET /user_ranks/1.xml
  def show
    @user_rank = UserRank.find(params[:id])

    respond_to do |format|
      format.html # show.html.erb
      format.xml  { render :xml => @user_rank }
    end
  end

  # GET /user_ranks/new
  # GET /user_ranks/new.xml
  def new
    @user_rank = UserRank.new
    @user_rank.setup_displays_for
    @user_rank.setup_conditions
    respond_to do |format|
      format.html # new.html.erb
      format.xml  { render :xml => @user_rank }
    end
  end

  # GET /user_ranks/1/edit
  def edit
    @user_rank = UserRank.find(params[:id])
  end

  # POST /user_ranks
  # POST /user_ranks.xml
  def create
    @user_rank = UserRank.new(params[:user_rank])

    respond_to do |format|
      if @user_rank.save
        flash[:notice] = '会員ランクを登録しました。'
        format.html { redirect_to(@user_rank) }
        format.xml  { render :xml => @user_rank, :status => :created, :location => @user_rank }
      else
        format.html { render :action => "new" }
        format.xml  { render :xml => @user_rank.errors, :status => :unprocessable_entity }
      end
    end
  end

  # PUT /user_ranks/1
  # PUT /user_ranks/1.xml
  def update
    @user_rank = UserRank.find(params[:id])

    respond_to do |format|
      if @user_rank.update_attributes(params[:user_rank])
        flash[:notice] = '会員ランクを更新しました。'
        format.html { redirect_to(@user_rank) }
        format.xml  { head :ok }
      else
        format.html { render :action => "edit" }
        format.xml  { render :xml => @user_rank.errors, :status => :unprocessable_entity }
      end
    end
  end

  # DELETE /user_ranks/1
  # DELETE /user_ranks/1.xml
  def destroy
    @user_rank = UserRank.find(params[:id])
    @user_rank.destroy

    respond_to do |format|
      format.html { redirect_to(user_ranks_url) }
      format.xml  { head :ok }
    end
  end
end
